==> geant4_10.5.1.orig.tar.gz: geant4-10.5.1/environments/g4py/tests/gtest01/module/QEventAction.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
// ====================================================================
//   QEventAction.cc
//
//                                         2005 Q
// ====================================================================
#include "QEventAction.hh"
#include "globals.hh"

// ====================================================================
//
// class description
//
// ====================================================================

////////////////////////////
QEventAction::QEventAction()
////////////////////////////
{
}


/////////////////////////////
QEventAction::~QEventAction()
/////////////////////////////
{
}


////////////////////////////////////////////////////////////
void QEventAction::BeginOfEventAction(const G4Event* aevent)
////////////////////////////////////////////////////////////
{
  G4cout << "QEventAction::BofEA is called." << G4endl;
}


//////////////////////////////////////////////////////////
void QEventAction::EndOfEventAction(const G4Event* aevent)
//////////////////////////////////////////////////////////
{
  G4cout << "QEventAction::EofEA is called." << G4endl;
}

==> geant4_10.7.4.orig.tar.gz: geant4-10.7.4/environments/g4py/tests/gtest01/module/QEventAction.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
// ====================================================================
//   QEventAction.cc
//
//                                         2005 Q
// ====================================================================
#include "QEventAction.hh"
#include "globals.hh"

// ====================================================================
//
// class description
//
// ====================================================================

////////////////////////////
QEventAction::QEventAction()
////////////////////////////
{
}


/////////////////////////////
QEventAction::~QEventAction()
/////////////////////////////
{
}


////////////////////////////////////////////////////////////
void QEventAction::BeginOfEventAction(const G4Event* /*aevent*/)
////////////////////////////////////////////////////////////
{
  G4cout << "QEventAction::BofEA is called." << G4endl;
}


//////////////////////////////////////////////////////////
void QEventAction::EndOfEventAction(const G4Event* /*aevent*/)
//////////////////////////////////////////////////////////
{
  G4cout << "QEventAction::EofEA is called." << G4endl;
}
